@@ -10,10 +10,9 @@ class MSSQLConnection(DBAPI):
 
     limit_re = re.compile('^\s*(select )(.*)', re.IGNORECASE)
 
-    def __init__(self, db, user, password='', host='localhost',
+    def __init__(self, db, user, password='', host='localhost', port=None,
                  autoCommit=0, **kw):
-        drivers = kw.pop('driver', None) or \
-            kw.pop('backend', None) or 'adodb,pymssql'
+        drivers = kw.pop('driver', None) or 'adodb,pymssql'
         for driver in drivers.split(','):
             driver = driver.strip()
             if not driver:
@@ -67,6 +66,7 @@ class MSSQLConnection(DBAPI):
 
         self.autoCommit=int(autoCommit)
         self.host = host
+        self.port = port
         self.db = db
         self.user = user
         self.password = password
@@ -74,12 +74,11 @@ class MSSQLConnection(DBAPI):
         self._can_use_max_types = None
         DBAPI.__init__(self, **kw)
 
-    def connectionFromURI(cls, uri):
-        user, password, host, port, path, args = cls._parseURI(uri)
+    @classmethod
+    def _connectionFromParams(cls, user, password, host, port, path, args):
         path = path.strip('/')
-        return cls(user=user, password=password, host=host or 'localhost',
-                   db=path, **args)
-    connectionFromURI = classmethod(connectionFromURI)
+        return cls(user=user, password=password,
+                   host=host or 'localhost', port=port, db=path, **args)
 
     def insert_id(self, conn):
         """
@@ -155,6 +154,7 @@ class MSSQLConnection(DBAPI):
             self.printDebug(conn, id, 'QueryIns', 'result')
         return id
 
+    @classmethod
     def _queryAddLimitOffset(cls, query, start, end):
         if end and not start:
             limit_str = "SELECT TOP %i" % end
@@ -164,7 +164,6 @@ class MSSQLConnection(DBAPI):
                 return ' '.join([limit_str, match.group(2)])
         else:
             return query
-    _queryAddLimitOffset = classmethod(_queryAddLimitOffset)
 
     def createReferenceConstraint(self, soClass, col):
         return col.mssqlCreateReferenceConstraint()
